==> qtjambi-quickwidgets-5.15-sources.jar: io/qt/quick/widgets/QtJambi_LibraryUtilities.java <==
package io.qt.quick.widgets;

final class QtJambi_LibraryUtilities {
    static{
        try {
            io.qt.QtUtilities.initializePackage("io.qt.internal");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("libGLESv2"))
                io.qt.QtUtilities.loadUtilityLibrary("libGLESv2");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("libEGL"))
                io.qt.QtUtilities.loadUtilityLibrary("libEGL");
            if(io.qt.QtUtilities.isAvailableQtLibrary("ANGLE"))
                io.qt.QtUtilities.loadQtLibrary("ANGLE");
            io.qt.QtUtilities.loadQtLibrary("Gui");
            io.qt.QtUtilities.loadQtLibrary("Network");
            io.qt.QtUtilities.loadQtLibrary("Qml");
            io.qt.QtUtilities.loadQtLibrary("QmlModels");
            io.qt.QtUtilities.loadQtLibrary("Quick");
            io.qt.QtUtilities.loadQtLibrary("Widgets");
            io.qt.QtUtilities.loadQtLibrary("QuickWidgets");
            io.qt.QtUtilities.loadQtJambiLibrary("QuickWidgets");
        } catch(RuntimeException | Error t) {
            throw t;
        } catch(Throwable t) {
            throw new RuntimeException(t);
        }
    }

    static final io.qt.InternalAccess internal = internalAccess();

    private static native io.qt.InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws java.lang.InstantiationError { throw new java.lang.InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}

==> qtjambi-quickwidgets-5.15.6-sources.jar: io/qt/quick/widgets/QtJambi_LibraryUtilities.java <==
package io.qt.quick.widgets;

final class QtJambi_LibraryUtilities {

    final static int qtMajorVersion = 5;

    final static int qtMinorVersion = 15;

    final static int qtJambiPatch = 6;

    static{
        try {
            io.qt.QtUtilities.initializePackage("io.qt.internal");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("libGLESv2"))
                io.qt.QtUtilities.loadUtilityLibrary("libGLESv2");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("libEGL"))
                io.qt.QtUtilities.loadUtilityLibrary("libEGL");
            if(io.qt.QtUtilities.isAvailableQtLibrary("ANGLE"))
                io.qt.QtUtilities.loadQtLibrary("ANGLE");
            io.qt.QtUtilities.loadQtLibrary("Gui");
            io.qt.QtUtilities.loadQtLibrary("Network");
            io.qt.QtUtilities.loadQtLibrary("Qml");
            io.qt.QtUtilities.loadQtLibrary("QmlModels");
            io.qt.QtUtilities.loadQtLibrary("Quick");
            io.qt.QtUtilities.loadQtLibrary("Widgets");
            io.qt.QtUtilities.loadQtLibrary("QuickWidgets");
            io.qt.QtUtilities.loadQtJambiLibrary("QuickWidgets");
        } catch(Error t) {
            throw t;
        } catch(Throwable t) {
            throw new ExceptionInInitializerError(t);
        }
    }
    static final io.qt.InternalAccess internal = internalAccess();

    private static native io.qt.InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws java.lang.InstantiationError { throw new java.lang.InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}
